A helper function which processes and displays the documentation part for each app
Source:R/generate_documentation.R
generate_documentation.RdThis function take the documentation provided as html file and extracts sections to generate the tabs with content for each Shiny app. This is a helper function and only useful for this package.